@@ -1,8 +1,8 @@
 import logging
 from fractions import Fraction
-from dftt_dispatch import InstanceMethodDispatch
-from error import DFTTTimecodeValueError, DFTTTimecodeTypeError
-from pattern import *
+from dftt_timecode.dispatch import InstanceMethodDispatch
+from dftt_timecode.error import DFTTTimecodeValueError, DFTTTimecodeTypeError
+from dftt_timecode.pattern import *
 from math import ceil
 
 logging.basicConfig(filename='dftt_timecode_log.txt',
@@ -20,32 +20,32 @@ class DfttTimecode:
     __strict = True  # 严格模式，默认为真，在该模式下不允许超出24或小于0的时码，将自动平移至0-24范围内，例如-1小时即为23小时，25小时即为1小时
     __precise_time = 0.0  # 精准时间戳，是所有时码类对象的工作基础
 
-    @InstanceMethodDispatch.dispatch()
+    @InstanceMethodDispatch.dispatch()  # 用InstanceMethodDispatch实现多构造函数
     def __init__(self, timecode_value, timecode_type, fps, drop_frame, strict):  # 构造函数
         pass
 
-    @InstanceMethodDispatch.register('__init__', str)
+    @InstanceMethodDispatch.register('__init__', str)  # 若传入的TC值为字符串，则调用此函数
     def _(self, timecode_value, timecode_type='auto', fps=24.0, drop_frame=False, strict=True):
-        if timecode_value[0] == '-':
+        if timecode_value[0] == '-':  # 判断首位是否为负，并为flag赋值
             minus_flag = True
         else:
             minus_flag = False
         self.__fps = fps
-        self.__nominal_fps = ceil(fps)  # 读入帧率取整为名义帧率便于后续计算
+        self.__nominal_fps = ceil(fps)  # 读入帧率取整为名义帧率便于后续计算（包括判断时码是否合法，DF/NDF逻辑等）
         self.__drop_frame = drop_frame
         self.__strict = strict
-        if round(self.__fps, 2) % 29.97 != 0 and self.__drop_frame == True:
+        if round(self.__fps, 2) % 29.97 != 0 and self.__drop_frame == True:  # 判断丢帧状态与时码输入是否匹配 不匹配则强制转换
             self.__drop_frame = False
             logging.log(20, 'Timecode.__init__.str: This FPS is NOT Drop-Framable, force drop_frame to False')
         else:
             pass
-        if timecode_type == 'auto':
-            if SMPTE_NDF_REGEX.match(timecode_value):
+        if timecode_type == 'auto':  # 自动判断类型逻辑
+            if SMPTE_NDF_REGEX.match(timecode_value):  # SMPTE NDF 强制DF为False
                 timecode_type = 'smpte'
                 self.__drop_frame = False
             elif SMPTE_DF_REGEX.match(timecode_value):
                 timecode_type = 'smpte'
-                if round(self.__fps, 2) % 29.97 == 0:
+                if round(self.__fps, 2) % 29.97 == 0:  # 判断丢帧状态与帧率是否匹配 不匹配则强制转换
                     self.__drop_frame = True
                 else:
                     self.__drop_frame = False
@@ -64,20 +64,20 @@ class DfttTimecode:
             else:
                 pass
         else:
-            pass
+            pass  # 这里不用elif是因为auto类型也需要利用下面的部分进行操作
         if timecode_type == 'smpte':  # smpte TC
-            if SMPTE_REGEX.match(timecode_value):
+            if SMPTE_REGEX.match(timecode_value):  # 判断输入是否符合SMPTE类型
                 pass
             else:
                 logging.log(40, 'Timecode.__init__.smpte: Timecode type DONOT match input value! Check input.')
                 raise DFTTTimecodeTypeError
             self.__type = timecode_type
-            temp_timecode_list = [int(x) if x else 0 for x in SMPTE_REGEX.match(timecode_value).groups()]
+            temp_timecode_list = [int(x) if x else 0 for x in SMPTE_REGEX.match(timecode_value).groups()]  # 正则取值
             hh = temp_timecode_list[0]
             mm = temp_timecode_list[1]
             ss = temp_timecode_list[2]
             ff = temp_timecode_list[3]
-            if ff > self.__nominal_fps - 1:
+            if ff > self.__nominal_fps - 1:  # 判断输入帧号在当前帧率下是否合法
                 logging.log(40,
                             'Timecode.__init__.smpte: This timecode is illegal under given params, check your input!')
                 raise DFTTTimecodeValueError
@@ -87,7 +87,7 @@ class DfttTimecode:
                 frame_index = ff + self.__nominal_fps * (ss + mm * 60 + hh * 3600)
             else:
                 drop_per_min = self.__nominal_fps / 30 * 2
-                if mm % 10 != 0 and ff in (0, drop_per_min - 1):
+                if mm % 10 != 0 and ff in (0, drop_per_min - 1):  # 检查是否有DF下不合法的帧号
                     logging.log(40,
                                 'Timecode.__init__.smpte: This timecode is illegal under given params, check your input!')
                     raise DFTTTimecodeValueError
@@ -97,25 +97,20 @@ class DfttTimecode:
                             self.__nominal_fps / 30) * 2 * (
                                           total_minutes - total_minutes // 10)  # 逢十分钟不丢帧 http://andrewduncan.net/timecodes/
             if self.__strict == True:  # strict输入逻辑
-                if minus_flag == False:
-                    frame_index = frame_index % (self.__fps * 86400) if self.__drop_frame == True else frame_index % (
-                            self.__nominal_fps * 86400)  # 对于DF时码来说，严格处理取真实FPS的模，对于非DF时码，则取名义FPS的模
-                else:
-                    frame_index = frame_index % (self.__fps * 86400) if self.__drop_frame == True else frame_index % (
-                            self.__nominal_fps * 86400)  # 对于DF时码来说，严格处理取真实FPS的模，对于非DF时码，则取名义FPS的模
-                    frame_index = self.__fps * 86400 - frame_index
+                frame_index = frame_index % (self.__fps * 86400) if self.__drop_frame == True else frame_index % (
+                        self.__nominal_fps * 86400)  # 对于DF时码来说，严格处理取真实FPS的模，对于NDF时码，则取名义FPS的模
             else:
                 pass
-            self.__precise_time = Fraction(frame_index / self.__fps)
+            self.__precise_time = Fraction(frame_index / self.__fps)  # 时间戳=帧号/帧率
         elif timecode_type == 'srt':  # srt字幕
-            if SRT_REGEX.match(timecode_value):
+            if SRT_REGEX.match(timecode_value):  # 判断输入是否符合SRT类型
                 pass
             else:
                 logging.log(40, 'Timecode.__init__.srt: Timecode type DONOT match input value! Check input.')
                 raise DFTTTimecodeTypeError
             self.__type = timecode_type
             temp_timecode_list = [int(x) if x else 0 for x in SRT_REGEX.match(timecode_value).groups()]
-            # 由于SRT不存在帧率，将为SRT赋予默认帧率和丢帧状态
+            # 由于SRT格式本身不存在帧率，将为SRT赋予默认帧率和丢帧状态
             logging.log(20,
                         'Timecode.__init__.srt: SRT timecode framerate ' + str(self.__fps) + ', DF=' + str(
                             self.__drop_frame) + " assigned")
@@ -124,6 +119,10 @@ class DfttTimecode:
             ss = temp_timecode_list[2]
             sub_sec = temp_timecode_list[3]  # 取毫秒
             self.__precise_time = Fraction(hh * 3600 + mm * 60 + ss + sub_sec / 1000)
+            if self.__strict == True:  # strict逻辑 对于非帧相关值（时间戳） 直接取模
+                self.__precise_time = self.__precise_time % 86400
+            else:
+                pass
         elif timecode_type == 'dlp':  # cinecanvas字幕
             if DLP_REGEX.match(timecode_value):
                 pass
@@ -139,8 +138,13 @@ class DfttTimecode:
             hh = temp_timecode_list[0]
             mm = temp_timecode_list[1]
             ss = temp_timecode_list[2]
-            sub_sec = temp_timecode_list[3]  # 取子帧戳
+            sub_sec = temp_timecode_list[3]  # 取子帧戳 dlp每秒共250个子帧 即4ms一个
+            # 详见https://interop-docs.cinepedia.com/Reference_Documents/CineCanvas(tm)_RevC.pdf 第17页 “TimeIn”部分
             self.__precise_time = Fraction(hh * 3600 + mm * 60 + ss + sub_sec / 250)
+            if self.__strict == True:  # strict逻辑 对于非帧相关值（时间戳） 直接取模
+                self.__precise_time = self.__precise_time % 86400
+            else:
+                pass
         elif timecode_type == 'ffmpeg':  # ffmpeg时间
             if FFMPEG_REGEX.match(timecode_value):
                 pass
@@ -154,6 +158,10 @@ class DfttTimecode:
             ss = temp_timecode_list[2]
             sub_sec = temp_timecode_list[3]
             self.__precise_time = Fraction(hh * 3600 + mm * 60 + ss + float('0.{}'.format(sub_sec)))
+            if self.__strict == True:  # strict逻辑 对于非帧相关值（时间戳） 直接取模
+                self.__precise_time = self.__precise_time % 86400
+            else:
+                pass
         elif timecode_type == 'fcpx':  # fcpx xml时间戳
             if FCPX_REGEX.match(timecode_value):
                 pass
@@ -163,7 +171,10 @@ class DfttTimecode:
             self.__type = timecode_type
             temp_timecode_list = [int(x) if x else 0 for x in FCPX_REGEX.match(timecode_value).groups()]
             self.__precise_time = Fraction(temp_timecode_list[0], temp_timecode_list[1])
-            pass
+            if self.__strict == True:  # strict逻辑 对于非帧相关值（时间戳） 直接取模
+                self.__precise_time = self.__precise_time % 86400
+            else:
+                pass
         elif timecode_type == 'frame':  # 帧计数
             if FRAME_REGEX.match(timecode_value):
                 pass
@@ -171,7 +182,7 @@ class DfttTimecode:
                 logging.log(40, 'Timecode.__init__.frame: Timecode type DONOT match input value! Check input.')
                 raise DFTTTimecodeTypeError
             self.__type = timecode_type
-            temp_frame_index = int(FRAME_REGEX.match(timecode_value).group(1))  # 注意，此处的TC指的实际上是帧计数
+            temp_frame_index = int(FRAME_REGEX.match(timecode_value).group(1))
             if self.__strict == True:  # 严格模式，对于丢帧时码而言 用实际FPS运算，对于不丢帧时码而言，使用名义FPS运算
                 temp_frame_index = temp_frame_index % (
                         self.__fps * 86400) if self.__drop_frame == True else temp_frame_index % (
@@ -188,12 +199,8 @@ class DfttTimecode:
             self.__type = timecode_type
             temp_timecode_value = TIME_REGEX.match(timecode_value).group(1)
             self.__precise_time = Fraction(temp_timecode_value)  # 内部时间戳直接等于输入值
-            if self.__strict == True:
-                temp_frame_index = round(self.__precise_time * self.__fps)
-                temp_frame_index = temp_frame_index % (
-                        self.__fps * 86400) if self.__drop_frame == True else temp_frame_index % (
-                        self.__nominal_fps * 86400)  # 对于DF时码来说，严格处理取真实FPS的模，对于非DF时码，则取名义FPS的模
-                self.__precise_time = Fraction(temp_frame_index / self.__fps)
+            if self.__strict == True:  # strict逻辑 对于非帧相关值（时间戳） 直接取模
+                self.__precise_time = self.__precise_time % 86400
             else:
                 pass
         else:
@@ -202,102 +209,122 @@ class DfttTimecode:
             self.__fps) + ', dropframe=' + str(self.__drop_frame) + ', strict=' + str(self.__strict)
         logging.log(10, instance_success_log)
 
-    @InstanceMethodDispatch.register('__init__', Fraction)
+    @InstanceMethodDispatch.register('__init__', Fraction)  # 输入为Fraction类分数，此时认为输入是时间戳，若不是，则会报错
     def _(self, timecode_value, timecode_type='time', fps=24.0, drop_frame=False, strict=True):
-        self.__type = timecode_type
-        self.__fps = fps
-        self.__nominal_fps = ceil(fps)
-        self.__drop_frame = drop_frame
-        self.__strict = strict
-        self.__precise_time = timecode_value  # 内部时间戳直接等于输入值
-        if self.__strict == True:
-            temp_frame_index = round(self.__precise_time * self.__fps)
-            temp_frame_index = temp_frame_index % (
-                    self.__fps * 86400) if self.__drop_frame == True else temp_frame_index % (
-                    self.__nominal_fps * 86400)  # 对于DF时码来说，严格处理取真实FPS的模，对于非DF时码，则取名义FPS的模
-            self.__precise_time = Fraction(temp_frame_index / self.__fps)
+        if timecode_type in ('time', 'auto'):
+            self.__type = 'time'
+            self.__fps = fps
+            self.__nominal_fps = ceil(fps)
+            self.__drop_frame = drop_frame
+            self.__strict = strict
+            self.__precise_time = timecode_value  # 内部时间戳直接等于输入值
+            if self.__strict == True:  # strict逻辑 对于非帧相关值（时间戳） 直接取模
+                self.__precise_time = self.__precise_time % 86400
+            else:
+                pass
         else:
-            pass
-        instance_success_log = 'Timecode.__init__.fraction: Timecode instance, type=' + str(
-            self.__type) + ', fps=' + str(self.__fps) + ', dropframe=' + str(self.__drop_frame) + ', strict=' + str(
-            self.__strict)
+            logging.log(40, 'Timecode.__init__.Fraction: Timecode type DONOT match input value! Check input.')
+            raise DFTTTimecodeTypeError
+        instance_success_log = 'Timecode.__init__.Fraction: Timecode instance, type=' + str(
+            self.__type) + ', fps=' + str(
+            self.__fps) + ', dropframe=' + str(self.__drop_frame) + ', strict=' + str(self.__strict)
         logging.log(10, instance_success_log)
 
     @InstanceMethodDispatch.register('__init__', int)
     def _(self, timecode_value, timecode_type='frame', fps=24.0, drop_frame=False, strict=True):
-        self.__type = timecode_type
-        self.__fps = fps
-        self.__nominal_fps = ceil(fps)
-        self.__drop_frame = drop_frame
-        self.__strict = strict
-        temp_frame_index = timecode_value
-        if self.__strict == True:
-            temp_frame_index = temp_frame_index % (
-                    self.__fps * 86400) if self.__drop_frame == True else temp_frame_index % (
-                    self.__nominal_fps * 86400)  # 对于DF时码来说，严格处理取真实FPS的模，对于非DF时码，则取名义FPS的模
+        if timecode_value < 0:
+            minus_flag = True
         else:
-            pass
-        self.__precise_time = Fraction(temp_frame_index / self.__fps)
-        instance_success_log = 'Timecode.__init__.int: Timecode instance, type=' + str(self.__type) + ', fps=' + str(
+            minus_flag = False
+        if timecode_type in ('frame', 'auto'):
+            self.__type = 'frame'
+            self.__fps = fps
+            self.__nominal_fps = ceil(fps)
+            self.__drop_frame = drop_frame
+            self.__strict = strict
+            temp_frame_index = timecode_value
+            if self.__strict == True:
+                temp_frame_index = temp_frame_index % (
+                        self.__fps * 86400) if self.__drop_frame == True else temp_frame_index % (
+                        self.__nominal_fps * 86400)
+            else:
+                pass
+            self.__precise_time = Fraction(temp_frame_index / self.__fps)
+        elif timecode_type == 'time':
+            self.__type = 'time'
+            self.__fps = fps
+            self.__nominal_fps = ceil(fps)
+            self.__drop_frame = drop_frame
+            self.__strict = strict
+            self.__precise_time = timecode_value  # 内部时间戳直接等于输入值
+            if self.__strict == True:  # strict逻辑 对于非帧相关值（时间戳） 直接取模
+                self.__precise_time = self.__precise_time % 86400
+            else:
+                pass
+        else:
+            logging.log(40, 'Timecode.__init__.int: Timecode type DONOT match input value! Check input.')
+            raise DFTTTimecodeTypeError
+        instance_success_log = 'Timecode.__init__.int: Timecode instance, type=' + str(
+            self.__type) + ', fps=' + str(
             self.__fps) + ', dropframe=' + str(self.__drop_frame) + ', strict=' + str(self.__strict)
         logging.log(10, instance_success_log)
 
     @InstanceMethodDispatch.register('__init__', float)
     def _(self, timecode_value, timecode_type='time', fps=24.0, drop_frame=False, strict=True):
-        self.__type = timecode_type
-        self.__fps = fps
-        self.__nominal_fps = ceil(fps)
-        self.__drop_frame = drop_frame
-        self.__strict = strict
-        self.__precise_time = Fraction(timecode_value)  # 内部时间戳直接等于输入值
-        if self.__strict == True:
-            temp_frame_index = round(self.__precise_time * self.__fps)
-            temp_frame_index = temp_frame_index % (
-                    self.__fps * 86400) if self.__drop_frame == True else temp_frame_index % (
-                    self.__nominal_fps * 86400)  # 对于DF时码来说，严格处理取真实FPS的模，对于非DF时码，则取名义FPS的模
-            self.__precise_time = Fraction(temp_frame_index / self.__fps)
+        if timecode_type in ('time', 'auto'):
+            self.__type = 'time'
+            self.__fps = fps
+            self.__nominal_fps = ceil(fps)
+            self.__drop_frame = drop_frame
+            self.__strict = strict
+            self.__precise_time = Fraction(timecode_value)  # 内部时间戳直接等于输入值
+            if self.__strict == True:
+                self.__precise_time = self.__precise_time % 86400
+            else:
+                pass
         else:
-            pass
+            logging.log(40, 'Timecode.__init__.float: Timecode type DONOT match input value! Check input.')
+            raise DFTTTimecodeTypeError
         instance_success_log = 'Timecode.__init__.float: Timecode instance, type=' + str(self.__type) + ', fps=' + str(
             self.__fps) + ', dropframe=' + str(self.__drop_frame) + ', strict=' + str(self.__strict)
         logging.log(10, instance_success_log)
 
     @InstanceMethodDispatch.register('__init__', tuple)
     def _(self, timecode_value, timecode_type='time', fps=24.0, drop_frame=False, strict=True):
-        self.__type = timecode_type
-        self.__fps = fps
-        self.__nominal_fps = ceil(fps)
-        self.__drop_frame = drop_frame
-        self.__strict = strict
-        self.__precise_time = Fraction(int(timecode_value[0]), int(timecode_value[1]))  # 将tuple输入视为分数
-        if self.__strict == True:
-            temp_frame_index = round(self.__precise_time * self.__fps)
-            temp_frame_index = temp_frame_index % (
-                    self.__fps * 86400) if self.__drop_frame == True else temp_frame_index % (
-                    self.__nominal_fps * 86400)  # 对于DF时码来说，严格处理取真实FPS的模，对于非DF时码，则取名义FPS的模
-            self.__precise_time = Fraction(temp_frame_index / self.__fps)
+        if timecode_type in ('time', 'auto'):
+            self.__type = 'time'
+            self.__fps = fps
+            self.__nominal_fps = ceil(fps)
+            self.__drop_frame = drop_frame
+            self.__strict = strict
+            self.__precise_time = Fraction(int(timecode_value[0]), int(timecode_value[1]))  # 将tuple输入视为分数
+            if self.__strict == True:
+                self.__precise_time = self.__precise_time % 86400
+            else:
+                pass
         else:
-            pass
+            logging.log(40, 'Timecode.__init__.tuple: Timecode type DONOT match input value! Check input.')
+            raise DFTTTimecodeTypeError
         instance_success_log = 'Timecode.__init__.tuple: Timecode instance, type=' + str(self.__type) + ', fps=' + str(
             self.__fps) + ', dropframe=' + str(self.__drop_frame) + ', strict=' + str(self.__strict)
         logging.log(10, instance_success_log)
 
     @InstanceMethodDispatch.register('__init__', list)
     def _(self, timecode_value, timecode_type='time', fps=24.0, drop_frame=False, strict=True):
-        self.__type = timecode_type
-        self.__fps = fps
-        self.__nominal_fps = ceil(fps)
-        self.__drop_frame = drop_frame
-        self.__strict = strict
-        self.__precise_time = Fraction(int(timecode_value[0]), int(timecode_value[1]))  # 将list输入视为分数
-        if self.__strict == True:
-            temp_frame_index = round(self.__precise_time * self.__fps)
-            temp_frame_index = temp_frame_index % (
-                    self.__fps * 86400) if self.__drop_frame == True else temp_frame_index % (
-                    self.__nominal_fps * 86400)  # 对于DF时码来说，严格处理取真实FPS的模，对于非DF时码，则取名义FPS的模
-            self.__precise_time = Fraction(temp_frame_index / self.__fps)
+        if timecode_type in ('time', 'auto'):
+            self.__type = timecode_type
+            self.__fps = fps
+            self.__nominal_fps = ceil(fps)
+            self.__drop_frame = drop_frame
+            self.__strict = strict
+            self.__precise_time = Fraction(int(timecode_value[0]), int(timecode_value[1]))  # 将list输入视为分数
+            if self.__strict == True:
+                self.__precise_time = self.__precise_time % 86400
+            else:
+                pass
         else:
-            pass
+            logging.log(40, 'Timecode.__init__.list: Timecode type DONOT match input value! Check input.')
+            raise DFTTTimecodeTypeError
         instance_success_log = 'Timecode.__init__.list: Timecode instance, type=' + str(self.__type) + ', fps=' + str(
             self.__fps) + ', dropframe=' + str(self.__drop_frame) + ', strict=' + str(self.__strict)
         logging.log(10, instance_success_log)
@@ -518,13 +545,14 @@ class DfttTimecode:
         if is_strict == self.__strict:
             pass
         else:
-            temp_timecode_object = DfttTimecode(self.__precise_time, self.__type, self.__fps, self.__drop_frame, is_strict)
+            temp_timecode_object = DfttTimecode(self.__precise_time, self.__type, self.__fps, self.__drop_frame,
+                                                is_strict)
             self.__precise_time = temp_timecode_object.__precise_time
         return self
 
     def __repr__(self):
         return '<DfttTimecode>({}{}, {}{}, {}{:.02f} {})'.format('Time Stamp:', self.timecode_output('time'),
-                                                                 'Type:', self.__type, 'FPS:', self.__fps,
+                                                                 'Type:', self.__type, 'FPS:', float(self.__fps),
                                                                  'DF' if self.__drop_frame == True else 'NDF')
 
     def __add__(self, other):  # 运算符重载，加号，加int则认为是帧，加float则认为是时间
@@ -611,14 +639,14 @@ class DfttTimecode:
             logging.log(30, 'Timecode.__rtruediv__: Undefined division, will return the latter Timecode object.')
         return self
 
-    def __eq__(self, other):
-        if isinstance(other, DfttTimecode):
+    def __eq__(self, other):  # 判断相等
+        if isinstance(other, DfttTimecode):  # 与另一个Timecode对象比较 比双方的时间戳 精确到5位小数
             return round(self.__precise_time, 5) == round(other.__precise_time, 5)
-        elif isinstance(other, int):
+        elif isinstance(other, int):  # 与int比较 默认int为帧号 比较当前timecode对象的帧号是否与其一致
             return int(self.timecode_output('frame')) == other
-        elif isinstance(other, float):
+        elif isinstance(other, float):  # 与float比较 默认float为时间戳 比较当前timecode对象的时间戳是否与其一致 精确到5位小数
             return float(round(self.__precise_time, 5)) == round(other, 5)
-        elif isinstance(other, Fraction):
+        elif isinstance(other, Fraction):  # 与Fraction比较 默认Fraction为时间戳 比较当前timecode对象的时间戳是否与其一致 精确到5位小数
             return round(self.__precise_time, 5) == round(other, 5)
         else:
             logging.log(30, 'CANNOT compare with such data type, will return FALSE')
@@ -627,7 +655,7 @@ class DfttTimecode:
     def __ne__(self, other):
         return not self.__eq__(other)
 
-    def __lt__(self, other):
+    def __lt__(self, other):  # 详见__eq__
         if isinstance(other, DfttTimecode):
             return round(self.__precise_time, 5) < round(other.__precise_time, 5)
         elif isinstance(other, int):
@@ -640,7 +668,7 @@ class DfttTimecode:
             logging.log(30, 'CANNOT compare with such data type, will return FALSE')
             return False
 
-    def __le__(self, other):
+    def __le__(self, other):  # 详见__eq__
         if isinstance(other, DfttTimecode):
             return round(self.__precise_time, 5) <= round(other.__precise_time, 5)
         elif isinstance(other, int):
@@ -653,7 +681,7 @@ class DfttTimecode:
             logging.log(30, 'CANNOT compare with such data type, will return FALSE')
             return False
 
-    def __gt__(self, other):
+    def __gt__(self, other):  # 详见__eq__
         if isinstance(other, DfttTimecode):
             return round(self.__precise_time, 5) > round(other.__precise_time, 5)
         elif isinstance(other, int):
@@ -666,7 +694,7 @@ class DfttTimecode:
             logging.log(30, 'CANNOT compare with such data type, will return FALSE')
             return False
 
-    def __ge__(self, other):
+    def __ge__(self, other):  # 详见__eq__
         if isinstance(other, DfttTimecode):
             return round(self.__precise_time, 5) >= round(other.__precise_time, 5)
         elif isinstance(other, int):
@@ -679,6 +707,5 @@ class DfttTimecode:
             logging.log(30, 'CANNOT compare with such data type, will return FALSE')
             return False
 
-    def __neg__(self):
+    def __neg__(self):  # 取负操作 返回时间戳取负的Timecode对象（strict规则照常应用 例如01:00:00:00 strict的对象 取负后为23:00:00:00）
         return DfttTimecode(-self.__precise_time, self.__type, self.__fps, self.__drop_frame, self.__strict)
-
